@@ -534,6 +534,38 @@ import_expr <- list(
       dplyr::mutate(
         Datetime = lubridate::force_tz(Datetime, tz = tz)
       )
+  }),
+  #Clouclip
+  Clouclip = rlang::expr({
+    data <- 
+      readr::read_tsv(filename, 
+                      show_col_types = FALSE,
+                      n_max = n_max,
+                      locale = locale,
+                      id = "file.name",
+                      name_repair = "universal",
+                      ...
+                      )
+    data <- data |> 
+      dplyr::rename(Datetime = Date) |> 
+      dplyr::mutate(Datetime = lubridate::force_tz(Datetime, tz = tz),
+                    dplyr::across(c(Lux, Dis),
+                                  \(x) {
+                                    dplyr::case_when(
+                                      x == -1 ~ "sleep_mode",
+                                      x == 204 ~ "out_of_range"
+                                    )
+                                  }, .names = "{.col}_status"),
+                    Lux = dplyr::case_when(
+                      Lux == -1 ~ NA,
+                      .default = Lux
+                    ),
+                    Dis = dplyr::case_when(
+                      Dis == -1 ~ NA,
+                      Dis == 204 ~ NA,
+                      .default = Lux
+                    ),
+                    )
   })
 )
 
