@@ -6,15 +6,16 @@ test_that("filtering works", {
           end = "12:00:00", length = "5:00:00") %>% 
         dplyr::pull(Datetime) %>% 
         range()},
-    as.POSIXct(c("2023-08-15 07:00:01", "2023-08-20 11:59:51"), tz = "UTC")
-  )
+    as.POSIXct(c("2023-08-29 07:00:04", "2023-09-03 11:59:54"), 
+               tz = "Europe/Berlin"))
   #start argument
   expect_equal(
     {sample.data.environment %>% 
         filter_Time(start = "12:00:00") %>% 
         dplyr::pull(Datetime) %>% 
         range()},
-    as.POSIXct(c("2023-08-15 12:00:01", "2023-08-20 23:59:51"), tz = "UTC")
+    as.POSIXct(c("2023-08-29 12:00:04", "2023-09-03 23:59:54"), 
+               tz = "Europe/Berlin")
   )
   
   #length argument
@@ -23,7 +24,8 @@ test_that("filtering works", {
         filter_Time(length = "12:00:00") %>% 
         dplyr::pull(Datetime) %>% 
         range()},
-    as.POSIXct(c("2023-08-15 00:00:01", "2023-08-20 12:00:01"), tz = "UTC")
+    as.POSIXct(c("2023-08-29 00:00:04", "2023-09-03 12:00:04"), 
+               tz = "Europe/Berlin")
   )
   
   #giving a POSIXct datetime as a start
@@ -31,7 +33,8 @@ test_that("filtering works", {
     sample.data.environment %>% 
       filter_Time(
         start = .$Datetime[1000]) %>% dplyr::pull(Datetime) %>% min(),
-    as.POSIXct(c("2023-08-15 02:46:31"), tz = "UTC")
+    as.POSIXct(c("2023-08-29 02:46:34"), 
+               tz = "Europe/Berlin")
   )
   
 })
@@ -45,6 +48,6 @@ test_that("giving wrong input types gives an error", {
   expect_error(
     sample.data.environment %>% 
       filter_Time(
-        start = "2023-08-17 12:00:00")
+        start = "2023-08-31 12:00:00")
   )
 })
